span.fa-stack
  position relative

  i
    position absolute
    left 0
    top 0

  i:first-child
    position relative

  i.fa-cancel-cover
    font-size 75%
    left 40%
    top -30%
    color red

.g-large-image-expected
  opacity 0.5
